@@ -12,27 +12,34 @@
 #' Viole, F. (2017) "A Note on Stochastic Dominance." \url{https://ssrn.com/abstract=3002675}.
 #' @examples
 #' set.seed(123)
-#' x<-rnorm(100); y<-rnorm(100)
-#' NNS.FSD.uni(x,y)
+#' x<-rnorm(100) ; y<-rnorm(100)
+#' NNS.FSD.uni(x, y)
 #' @export
 
-NNS.FSD.uni <- function(x,y,type="discrete"){
-  if(min(y)>min(x)) {return(0)} else {
-  x_sort <- sort(x, decreasing=FALSE)
-  y_sort <- sort(y, decreasing=FALSE)
+NNS.FSD.uni <- function(x, y, type = "discrete"){
+  if(min(y) > min(x)){
+    return(0)
+    } else {
+      x_sort <- sort(x, decreasing = FALSE)
+      y_sort <- sort(y, decreasing = FALSE)
 
-  Combined = c(x_sort,y_sort)
-  Combined_sort = sort(Combined, decreasing=FALSE)
+      Combined = c(x_sort, y_sort)
+      Combined_sort = sort(Combined, decreasing = FALSE)
 
-  if(type=="discrete"){degree=0}else{degree=1}
-  L.x = LPM(degree,Combined_sort,x)
-  LPM_x_sort=L.x/(UPM(degree,Combined_sort,x)+L.x)
-  L.y = LPM(degree,Combined_sort,y)
-  LPM_y_sort=L.y/(UPM(degree,Combined_sort,y)+L.y)
+      if(type == "discrete"){
+        degree = 0
+      } else {
+          degree = 1
+      }
 
-  x.fsd.y=any(LPM_x_sort>LPM_y_sort)
+      L.x = LPM(degree, Combined_sort, x)
+      LPM_x_sort = L.x / (UPM(degree, Combined_sort, x) + L.x)
+      L.y = LPM(degree, Combined_sort, y)
+      LPM_y_sort = L.y / (UPM(degree, Combined_sort, y) + L.y)
 
-  ifelse(!x.fsd.y & min(x)>=min(y) & !identical(LPM_x_sort,LPM_y_sort),return(1),return(0))
+      x.fsd.y = any(LPM_x_sort > LPM_y_sort)
+
+      ifelse(!x.fsd.y & min(x) >= min(y) & !identical(LPM_x_sort, LPM_y_sort), return(1), return(0))
 
   }
 }
@@ -52,20 +59,22 @@ NNS.FSD.uni <- function(x,y,type="discrete"){
 #' @export
 
 
-NNS.SSD.uni <- function(x,y){
-  if(min(y)>min(x) | mean(y)>mean(x)) {return(0)} else {
-  x_sort <- sort(x, decreasing=FALSE)
-  y_sort <- sort(y, decreasing=FALSE)
+NNS.SSD.uni <- function(x, y){
+  if(min(y) > min(x) | mean(y) > mean(x)) {
+    return(0)
+    } else {
+      x_sort <- sort(x, decreasing = FALSE)
+      y_sort <- sort(y, decreasing = FALSE)
 
-  Combined = c(x_sort,y_sort)
-  Combined_sort = sort(Combined, decreasing=FALSE)
+      Combined = c(x_sort,y_sort)
+      Combined_sort = sort(Combined, decreasing = FALSE)
 
-  LPM_x_sort = LPM(1,Combined_sort,x)
-  LPM_y_sort = LPM(1,Combined_sort,y)
+      LPM_x_sort = LPM(1, Combined_sort, x)
+      LPM_y_sort = LPM(1, Combined_sort, y)
 
-    x.ssd.y=any(LPM_x_sort>LPM_y_sort)
+      x.ssd.y=any(LPM_x_sort > LPM_y_sort)
 
-    ifelse(!x.ssd.y & min(x)>=min(y) & !identical(LPM_x_sort,LPM_y_sort),return(1),return(0))
+      ifelse(!x.ssd.y & min(x) >= min(y) & !identical(LPM_x_sort, LPM_y_sort), return(1), return(0))
 
   }
 }
@@ -86,20 +95,22 @@ NNS.SSD.uni <- function(x,y){
 #' @export
 
 
-NNS.TSD.uni <- function(x,y){
-  if(min(y)>min(x) | mean(y)>mean(x)) {return(0)} else {
-  x_sort <- sort(x, decreasing=FALSE)
-  y_sort <- sort(y, decreasing=FALSE)
+NNS.TSD.uni <- function(x, y){
+  if(min(y) > min(x) | mean(y) > mean(x)) {
+    return(0)
+    } else {
+      x_sort <- sort(x, decreasing = FALSE)
+      y_sort <- sort(y, decreasing = FALSE)
 
-  Combined = c(x_sort,y_sort)
-  Combined_sort = sort(Combined, decreasing=FALSE)
+      Combined = c(x_sort, y_sort)
+      Combined_sort = sort(Combined, decreasing = FALSE)
 
-  LPM_x_sort = LPM(2,Combined_sort,x)
-  LPM_y_sort = LPM(2,Combined_sort,y)
+      LPM_x_sort = LPM(2, Combined_sort, x)
+      LPM_y_sort = LPM(2, Combined_sort, y)
 
-    x.tsd.y=any(LPM_x_sort>LPM_y_sort)
+      x.tsd.y = any(LPM_x_sort>LPM_y_sort)
 
-    ifelse(!x.tsd.y & min(x)>=min(y) & !identical(LPM_x_sort,LPM_y_sort),return(1),return(0))
+      ifelse(!x.tsd.y & min(x) >= min(y) & !identical(LPM_x_sort, LPM_y_sort), return(1), return(0))
 
   }
 }
